
# Slot: result child slot




URI: [http://example.org/sample/example1/result_child_slot](http://example.org/sample/example1/result_child_slot)


## Domain and Range

[Problem](Problem.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [MetricResultChild](MetricResultChild.md)
